@@ -10,7 +10,8 @@ from ..utils import support
 __all__ = ['odps_download_with_sql']
 
 
-def odps_download_with_sql(sql, save_path, connect=None, sep=',', tocache: bool = False, hints: dict = None):
+def odps_download_with_sql(sql, save_path, connect=None, sep=',', tocache: bool = False, hints: dict = None,
+                           header: bool = True) -> str:
     """通过SQL下载全量数据"""
     connect = connect or support.odps_connect()
     save_path = os.path.join(tocache and env.CACHE_PROJECT_HOME or env.PROJECT_HOME, save_path)
@@ -24,7 +25,8 @@ def odps_download_with_sql(sql, save_path, connect=None, sep=',', tocache: bool
         headers = reader.schema.names
         with open(save_path, 'w', encoding='utf8') as writefile:
             csv_writer = csv.writer(writefile, delimiter=sep)
-            csv_writer.writerow(headers)
+            if header:
+                csv_writer.writerow(headers)
             for record in reader:
                 csv_writer.writerow(dict(record).values())
     return save_path
