@@ -104,7 +104,7 @@ if __name__ == '__main__':
     print(split('a;b;;c', ';', '_', '.bin'))
     print(split(['a', 'b', 'c'], ';', '_', '.bin'))
     print('a;b;c'.split(';'))
-    print(list(remove_invalid_words('a\t \u0020b')))
+    # print(list(remove_invalid_words('a\t \u0020b')))
     print(is_number('123'))
     print(is_number('abc'))
     print(strip(';;;123;;;', ';', 1))
