@@ -35,6 +35,12 @@ def __get_exists_file(file: str):
 env_file = __get_exists_file('.env')
 env_file and __load_dotenv(env_file)
 
+def set_env_file(file: str):
+    """设置环境变量文件"""
+    global env_file
+    env_file = os.path.abspath(file)
+    env_file and __load_dotenv(env_file)
+
 
 # logging.info("current env file path is:[%s]" % env_file)
 
